@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.01.
 package Dancer2::Logger::LogReport;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 # ABSTRACT: Dancer2 logger engine for Log::Report
 
@@ -18,6 +18,9 @@ use Log::Report  'logreport', syntax => 'REPORT', mode => 'DEBUG';
 
 our $AUTHORITY = 'cpan:MARKOV';
 
+# all dispatchers shall be created exactly once (unique name)
+my %disp_objs;
+
 my %level_dancer2lr =
   ( core  => 'TRACE'
   , debug => 'TRACE'
@@ -32,14 +35,23 @@ has dispatchers =>
   , lazy  => 1
   );
 
-sub BUILD
-{   my $self = shift;
-    my $dispatchers = $self->dispatchers;
+sub BUILD ()
+{   my $self     = shift;
+    my $configs  = $self->dispatchers || {default => undef};
+    $self->{use} = [keys %$config];
 
-    foreach my $name (keys %$dispatchers)
-    {   my %dispatcher = %{$dispatchers->{$name}};
-        my $type       = delete $dispatcher{type};
-        dispatcher $type => $name, %dispatcher;
+    foreach my $name (keys %$configs)
+    {   my $config = $configs->{$name} || {};
+        if(keys %$config)
+        {   # cannot use log() output yet!  recursion!
+            ! $disp_objs{$name}
+                or die "attempt to reconfigure dispatcher $name";
+
+            my $type = delete $config->{type}
+                or die "dispatcher configuration $name without type";
+
+            $disp_objs{$name} = dispatcher $type, $name, %$config;
+        }
     }
 }
 
@@ -57,14 +69,12 @@ sub log($$$)
         $msg =~ s/\n+$//;
     }
 
-    # The levels are nearly the same.
+    # the levels are nearly the same.
     my $reason = $level_dancer2lr{$level} // uc $level;
 
-    report {is_fatal => 0}, $reason => $msg;
+    report {is_fatal => 0}, $reason => $msg, to => $self->{use};
 
     undef;
 }
  
-#--------------
-
 1;
