@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.01.
 package Dancer2::Plugin::LogReport;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 
 use warnings;
@@ -15,7 +15,7 @@ use Log::Report  'log-report', syntax => 'REPORT';
 
 use Scalar::Util qw/blessed/;
 
-my $_dsl;        # XXX How to avoid the global?
+my $_dsl;        # XXX How to avoid the global?   Dancer2::Core::DSL
 my $_settings;
 
 
@@ -42,7 +42,7 @@ on_plugin_import
             if $error->{exception};
     });
 
-    if ($settings->{handle_http_errors})
+    if($settings->{handle_http_errors})
     {   # Need after_error for HTTP errors (eg 404) so as to
         # be able to change the forwarding location
         $dsl->hook(after_error => sub {
@@ -134,10 +134,14 @@ sub _error_handler($$$$)
         # out. With the former, the exception will have been
         # re-thrown as a non-fatal exception, so check that.
       , ERROR   => sub {
-            exists $options->{is_fatal} && !$options->{is_fatal}
-                ? _message_add( danger => $_[0] )
-                : _forward_home( $_dsl, danger => $_[0] );
-        }
+            return _message_add( danger => $_[0] )
+                if exists $options->{is_fatal} && !$options->{is_fatal};
+
+            return  _forward_home( $_dsl, danger => $_[0] )
+                if $_dsl->request->uri ne '/' || !$_dsl->request->is_get;
+
+            return;
+       }
 
         # 'FAULT', 'ALERT', 'FAILURE', 'PANIC'
         # All these are fatal errors. Display error to user, but
