@@ -8,7 +8,7 @@ use strict;
 
 package Log::Report;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 use base 'Exporter';
 
@@ -150,11 +150,14 @@ sub report($@)
 sub dispatcher($@)
 {   if($_[0] !~ m/^(?:close|find|list|disable|enable|mode|needs|filter)$/)
     {   my ($type, $name) = (shift, shift);
+
+        # old dispatcher with same name will be closed in DESTROY
+        delete $reporter->{dispatchers}{$name};
+
         my $disp = Log::Report::Dispatcher->new($type, $name
           , mode => $default_mode, @_);
         defined $disp or return;  # use defined, because $disp is overloaded
 
-        # old dispatcher with same name will be closed in DESTROY
         $reporter->{dispatchers}{$name} = $disp;
         _whats_needed;
         return ($disp);
@@ -207,7 +210,7 @@ sub dispatcher($@)
     }
 
     # find does require reinventarization
-    _whats_needed unless $command eq 'find';
+    _whats_needed if $command ne 'find';
 
     wantarray ? @dispatchers : $dispatchers[0];
 }
