@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher::Syslog;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 use base 'Log::Report::Dispatcher';
 
@@ -37,12 +37,19 @@ my %default_reasonToPrio =
     or panic __"not all reasons have a default translation";
 
 
+my $active;
+
 sub init($)
 {   my ($self, $args) = @_;
     $args->{format_reason} ||= 'IGNORE';
 
     $self->SUPER::init($args);
 
+    error __x"max one active syslog dispatcher, attempt for {new} have {old}"
+      , new => $self->name, old => $active
+        if $active;
+    $active   = $self->name;
+
     setlogsock(delete $args->{logsocket})
         if $args->{logsocket};
 
@@ -74,7 +81,9 @@ sub init($)
 
 sub close()
 {   my $self = shift;
+    undef $active;
     closelog;
+
     $self->SUPER::close;
 }
 
